@@ -13,6 +13,7 @@ use core::ops::SubAssign;
 
 use crate::lex_then;
 use crate::partial_then;
+use crate::scalar_mul;
 use crate::Integer;
 use crate::Vector;
 use crate::VectorOps;
@@ -304,63 +305,9 @@ impl<'a, S: Integer> Neg for &'a Vec2d<S> {
     }
 }
 
-impl Mul<Vec2d<i32>> for i32 {
-    type Output = Vec2d<i32>;
-
-    fn mul(self, other: Vec2d<i32>) -> Vec2d<i32> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec2d<i32>> for i32 {
-    type Output = Vec2d<i32>;
-
-    fn mul(self, other: &'a Vec2d<i32>) -> Vec2d<i32> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<Vec2d<i32>> for &'a i32 {
-    type Output = Vec2d<i32>;
-
-    fn mul(self, other: Vec2d<i32>) -> Vec2d<i32> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec2d<i32>> for &'a i32 {
-    type Output = Vec2d<i32>;
-
-    fn mul(self, other: &'a Vec2d<i32>) -> Vec2d<i32> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-
-impl Mul<Vec2d<i64>> for i64 {
-    type Output = Vec2d<i64>;
-
-    fn mul(self, other: Vec2d<i64>) -> Vec2d<i64> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec2d<i64>> for i64 {
-    type Output = Vec2d<i64>;
-
-    fn mul(self, other: &'a Vec2d<i64>) -> Vec2d<i64> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<Vec2d<i64>> for &'a i64 {
-    type Output = Vec2d<i64>;
-
-    fn mul(self, other: Vec2d<i64>) -> Vec2d<i64> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec2d<i64>> for &'a i64 {
-    type Output = Vec2d<i64>;
-
-    fn mul(self, other: &'a Vec2d<i64>) -> Vec2d<i64> {
-        Vec2d::with(|i| self * other[i])
-    }
-}
+scalar_mul!(i32, Vec2d<i32>);
+scalar_mul!(i64, Vec2d<i64>);
+scalar_mul!(i128, Vec2d<i128>);
 
 impl<S: Integer> Mul<Vec2d<S>> for Vec2d<S> {
     type Output = S;
