@@ -13,6 +13,7 @@ use core::ops::SubAssign;
 
 use crate::lex_then;
 use crate::partial_then;
+use crate::scalar_mul;
 use crate::Integer;
 use crate::Vector;
 use crate::VectorOps;
@@ -374,63 +375,9 @@ impl<'a, S: Integer> Neg for &'a Vec4d<S> {
     }
 }
 
-impl Mul<Vec4d<i32>> for i32 {
-    type Output = Vec4d<i32>;
-
-    fn mul(self, other: Vec4d<i32>) -> Vec4d<i32> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec4d<i32>> for i32 {
-    type Output = Vec4d<i32>;
-
-    fn mul(self, other: &'a Vec4d<i32>) -> Vec4d<i32> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<Vec4d<i32>> for &'a i32 {
-    type Output = Vec4d<i32>;
-
-    fn mul(self, other: Vec4d<i32>) -> Vec4d<i32> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec4d<i32>> for &'a i32 {
-    type Output = Vec4d<i32>;
-
-    fn mul(self, other: &'a Vec4d<i32>) -> Vec4d<i32> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-
-impl Mul<Vec4d<i64>> for i64 {
-    type Output = Vec4d<i64>;
-
-    fn mul(self, other: Vec4d<i64>) -> Vec4d<i64> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec4d<i64>> for i64 {
-    type Output = Vec4d<i64>;
-
-    fn mul(self, other: &'a Vec4d<i64>) -> Vec4d<i64> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<Vec4d<i64>> for &'a i64 {
-    type Output = Vec4d<i64>;
-
-    fn mul(self, other: Vec4d<i64>) -> Vec4d<i64> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
-impl<'a> Mul<&'a Vec4d<i64>> for &'a i64 {
-    type Output = Vec4d<i64>;
-
-    fn mul(self, other: &'a Vec4d<i64>) -> Vec4d<i64> {
-        Vec4d::with(|i| self * other[i])
-    }
-}
+scalar_mul!(i32, Vec4d<i32>);
+scalar_mul!(i64, Vec4d<i64>);
+scalar_mul!(i128, Vec4d<i128>);
 
 impl<S: Integer> Mul<Vec4d<S>> for Vec4d<S> {
     type Output = S;
